@@ -75,7 +75,7 @@ pub fn page_all(mut p: Pager) -> Result<(), PageAllError> {
         // If the number of lines in the output is less than the number of rows
         // or run_no_overflow is true
         // display everything and quit
-        if p.run_no_overflow && p.rows > p.num_lines() {
+        if !p.run_no_overflow && p.rows > p.num_lines() {
             let mut out = stdout.lock();
             utils::write_lines(&mut out, &mut p)?;
             out.flush()?;
